@@ -23,7 +23,8 @@ class Serializer(Generic[TSerialized]):
 
     @abstractmethod
     def serialize(
-            self, obj: TSerializable,
+            self, 
+            obj: TSerializable,
             schema: Optional[Type[TSerializable]] = None,
     ) -> TSerialized:
         """
